# Table of Contents

- [tech-categories-in-reference-catalog](<./tech-categories-in-reference-catalog.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Tech Categories in the Reference Catalog](<./Tech-Categories-in-the-Reference-Catalog.md>)
  - [Overview](<./Tech-Categories-in-the-Reference-Catalog/Overview.md>)
  - [Exploring the TBM Taxonomy](<./Tech-Categories-in-the-Reference-Catalog/Exploring-the-TBM-Taxonomy.md>)
  - [Evaluating the TBM Taxonomy: Key Considerations](<./Tech-Categories-in-the-Reference-Catalog/Evaluating-the-TBM-Taxonomy-Key-Considerations.md>)
  - [Importing Tech Categories from the Reference Catalog](<./Tech-Categories-in-the-Reference-Catalog/Importing-Tech-Categories-from-the-Reference-Catalog.md>)
  - [Was this page helpful?](<./Tech-Categories-in-the-Reference-Catalog/Was-this-page-helpful.md>)
